@@ -5,6 +5,9 @@ mkdir -p $LXC_ROOTFS_PATH
 cd $LXC_ROOTFS_PATH
 cat /boot/android-ramdisk.img | gzip -d | cpio -i
 
+# make sure the ubuntu_chroot init service does not get started
+sed -i '/ubuntu_chroot init$/,+2d' $LXC_ROOTFS_PATH/init.rc
+
 cp -a /var/lib/lxc/android/overrides/* $LXC_ROOTFS_PATH
 
 mkdir -p $LXC_ROOTFS_PATH/dev/pts
